==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/RadialPieSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialPieSeriesDescription } from "./RadialPieSeriesDescription";
/**
 * @hidden
 */
export let RadialPieSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialPieSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RadialPieSeriesDescriptionMetadata.a == null) {
                RadialPieSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialPieSeriesDescriptionMetadata.c(RadialPieSeriesDescriptionMetadata.a);
            }
            if (a.j(RadialPieSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(RadialPieSeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredRadialSeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            RadialPieSeriesDescriptionMetadata.b(a);
            a.aa("RadialPieSeries", () => new RadialPieSeriesDescription());
            a.z("RadialPieSeries", RadialPieSeriesDescriptionMetadata.a);
        }
    }
    RadialPieSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RadialPieSeriesDescriptionMetadata, 'RadialPieSeriesDescriptionMetadata');
    RadialPieSeriesDescriptionMetadata.a = null;
    return RadialPieSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/RadialPieSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialPieSeriesDescription } from "./RadialPieSeriesDescription";
/**
 * @hidden
 */
export let RadialPieSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RadialPieSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RadialPieSeriesDescriptionMetadata.a == null) {
                RadialPieSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RadialPieSeriesDescriptionMetadata.c(RadialPieSeriesDescriptionMetadata.a);
            }
            if (a.k(RadialPieSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(RadialPieSeriesDescriptionMetadata.a);
        }
        static c(a) {
            AnchoredRadialSeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            RadialPieSeriesDescriptionMetadata.b(a);
            a.ac("RadialPieSeries", () => new RadialPieSeriesDescription());
            a.ab("RadialPieSeries", RadialPieSeriesDescriptionMetadata.a);
        }
    }
    RadialPieSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RadialPieSeriesDescriptionMetadata, 'RadialPieSeriesDescriptionMetadata');
    RadialPieSeriesDescriptionMetadata.a = null;
    return RadialPieSeriesDescriptionMetadata;
})();
